==> qtisas_0.9.20.orig.tar.gz: qtisas-fixed/build.md <==
# QtiSAS

This software can be successfully build on systems having Qt5 library.

## Linux

    git clone --recurse-submodules https://iffgit.fz-juelich.de/qtisas/qtisas.git
    cd qtisas
    mkdir build
    cd build
    cmake .. -DCMAKE_C_COMPILER=/usr/bin/gcc -DCMAKE_CXX_COMPILER=/usr/bin/g++ \
        -DCMAKE_BUILD_TYPE=Release -DWITH_PYTHON=ON
    cmake --build . --parallel $(nproc)
    ../bin/qtisas

Generate .deb package:

    cpack -G DEB

Generate .rpm package:

    cpack -G RPM

### Dependencies

#### Ubuntu 18.04

    apt install cmake git wget \
        build-essential libhdf5-dev libtiff-dev libyaml-cpp-dev \
        qtbase5-dev libqt5svg5-dev \
        libpython3-dev pyqt5-dev pyqt5-dev-tools sip-dev python3-sip-dev

#### Ubuntu 22.04

    apt install -y cmake git wget \
        build-essential libhdf5-dev libtiff-dev libyaml-cpp-dev \
        qtbase5-dev libqt5svg5-dev \
        libpython3-dev pyqt5-dev python3-sipbuild python3-pyqtbuild sip-tools

#### Rocky Linux 8

    dnf install -y dnf-plugins-core
    dnf config-manager --set-enabled powertools
    dnf install -y epel-release
    dnf up -y
    dnf install -y cmake git wget \
        mesa-libGLU-devel hdf5-devel libtiff-devel yaml-cpp-devel zlib-devel \
        qt5-qtbase-devel qt5-qtsvg-devel \
        python3-qt5-devel

#### Rocky Linux 9

    dnf install -y dnf-plugins-core
    dnf config-manager --set-enabled devel
    dnf install -y epel-release
    dnf up -y
    dnf install -y cmake git wget \
        mesa-libGLU-devel hdf5-devel libtiff-devel yaml-cpp-devel zlib-devel \
        qt5-qtbase-devel qt5-qtsvg-devel \
        python3-devel python3-qt5-devel sip6 PyQt-builder

## Windows

Install following apps:

    git - https://git-scm.com/download/win
    cmake - https://cmake.org/download/
    mingw, Qt5 - https://www.qt.io/download-open-source
    python - https://www.python.org/ftp/python/
    hdf5 - https://www.hdfgroup.org/downloads/hdf5/
    libtiff - https://gnuwin32.sourceforge.net/packages/tiff.htm
    yaml-cpp - https://github.com/jbeder/yaml-cpp
    zlib - https://gnuwin32.sourceforge.net/packages/zlib.htm

GnuWin32 provides 32-bit versions of the libs, pay attention to compatibility
with the rest of the software. In this case hdf5 and yaml-cpp you have to build
yourself. This example assumes hdf5 and yaml-cpp are instaled to GnuWin32.
Alternately you can use MSYS or similar tools.

Add things to the path:

    C:\Program Files\Git\cmd
    C:\Program Files (x86)\CMake\bin
    C:\Qt\5.15.2\mingw81_32\bin
    C:\Qt\5.15.2\mingw81_32\plugins
    C:\Qt\Tools\mingw810_32\bin
    C:\Program Files (x86)\GnuWin32\bin
    C:\Users\kk\AppData\Local\Programs\Python\Python311-32
    C:\Users\kk\AppData\Local\Programs\Python\Python311-32\DLLs
    C:\Users\kk\AppData\Local\Programs\Python\Python311-32\Scripts
    bin folders of 3rdparty libs in qtisas\libs\Windows-AMD64\...

Use powershell to install few packages from pip:

    pip3.exe install pyqt5 pyqt-builder sip

Use PowerShell::

    git.exe clone --recurse-submodules https://iffgit.fz-juelich.de/qtisas/qtisas.git
    cd qtisas
    mkdir build
    cd build
    cmake.exe .. -G "Unix Makefiles" -DCMAKE_BUILD_TYPE=Release
        -DCMAKE_MAKE_PROGRAM="C:/Qt/Tools/mingw810_32/bin/mingw32-make.exe"
        -DCMAKE_C_COMPILER="C:/Qt/Tools/mingw810_32/bin/gcc.exe"
        -DCMAKE_CXX_COMPILER="C:/Qt/Tools/mingw810_32/bin/g++.exe"
        -DHDF5_ROOT="C:/Program Files (x86)/GnuWin32"
        -DTIFF_ROOT="C:/Program Files (x86)/GnuWin32"
        -Dyaml-cpp_ROOT="C:/Program Files (x86)/GnuWin32"
        -DZLIB_ROOT="C:/Program Files (x86)/GnuWin32"
        -DCMAKE_PREFIX_PATH="C:/Qt/5.15.2/mingw81_32"
        -DPython3_ROOT_DIR="C:/Users/kk/AppData/Local/Programs/Python/Python311-32"
        -DWITH_PYTHON=ON
    cmake.exe --build . --parallel $env:NUMBER_OF_PROCESSORS

If everything is available in path, run bin/qtisas.exe.

## MacOS

Xcode command line tools are prerequisite. Then a user might need brew or other
software packaging system. Once you have it:

    brew install cmake qt@5 hdf5 libtiff python3 pyqt@5 pyqt-builder sip scipy yaml-cpp

Clone the repository:

    git clone --recurse-submodules https://iffgit.fz-juelich.de/qtisas/qtisas.git

Build the software:

    cd qtisas
    mkdir build
    cd build
    cmake .. -DCMAKE_C_COMPILER=/usr/bin/clang -DCMAKE_CXX_COMPILER=/usr/bin/clang++
        -DCMAKE_PREFIX_PATH=/opt/homebrew/opt/qt@5
        -DPython3_ROOT_DIR=/opt/homebrew/opt/python@3
        -DCMAKE_BUILD_TYPE=Release -DWITH_PYTHON=ON
    cmake --build . --parallel $(sysctl -n hw.ncpu)
    open bin/qtisas.app

==> qtisas_0.9.22.orig.tar.gz: qtisas-fixed/build.md <==
# QtiSAS

This software can be successfully build on systems having Qt5 library.

## Linux

    git clone --recurse-submodules https://iffgit.fz-juelich.de/qtisas/qtisas.git
    cd qtisas
    mkdir build
    cd build
    cmake .. -DCMAKE_C_COMPILER=/usr/bin/gcc -DCMAKE_CXX_COMPILER=/usr/bin/g++ \
        -DCMAKE_BUILD_TYPE=Release -DWITH_PYTHON=ON
    cmake --build . --parallel $(nproc)
    ../bin/qtisas

Generate .deb package:

    cpack -G DEB

Generate .rpm package:

    cpack -G RPM

### Dependencies

#### Debian 12

    apt install -y cmake git wget \
        build-essential libhdf5-dev libtiff-dev libyaml-cpp-dev \
        qtbase5-dev libqt5svg5-dev \
        libpython3-dev pyqt5-dev python3-sipbuild python3-pyqtbuild sip-tools

#### Rocky Linux 9

    dnf install -y dnf-plugins-core
    dnf config-manager --set-enabled devel
    dnf install -y epel-release
    dnf up -y
    dnf install -y cmake git wget \
        mesa-libGLU-devel hdf5-devel libtiff-devel yaml-cpp-devel zlib-devel \
        qt5-qtbase-devel qt5-qtsvg-devel \
        python3-devel python3-qt5-devel sip6 PyQt-builder

## Windows

Install following apps:

    git - https://git-scm.com/download/win
    cmake - https://cmake.org/download/
    mingw, Qt5 - https://www.qt.io/download-open-source
    python - https://www.python.org/ftp/python/
    hdf5 - https://www.hdfgroup.org/downloads/hdf5/
    libtiff - https://gnuwin32.sourceforge.net/packages/tiff.htm
    yaml-cpp - https://github.com/jbeder/yaml-cpp
    zlib - https://gnuwin32.sourceforge.net/packages/zlib.htm

GnuWin32 provides 32-bit versions of the libs, pay attention to compatibility
with the rest of the software. In this case hdf5 and yaml-cpp you have to build
yourself. This example assumes hdf5 and yaml-cpp are installed to GnuWin32.
Alternately you can use MSYS or similar tools. Or use our precompiled set of
libs from [here](https://fz-juelich.sciebo.de/s/r5EBcbXdTipwTkA).

Add things to the path:

    C:\Program Files\Git\cmd
    C:\Program Files (x86)\CMake\bin
    C:\Qt\5.15.2\mingw81_32\bin
    C:\Qt\5.15.2\mingw81_32\plugins
    C:\Qt\Tools\mingw810_32\bin
    C:\Program Files (x86)\GnuWin32\bin
    C:\Users\kk\AppData\Local\Programs\Python\Python311-32
    C:\Users\kk\AppData\Local\Programs\Python\Python311-32\DLLs
    C:\Users\kk\AppData\Local\Programs\Python\Python311-32\Scripts
    bin folders of 3rdparty libs in qtisas\libs\Windows-...\...

Use powershell to install few packages from pip:

    pip3.exe install pyqt5 pyqt-builder sip

Use PowerShell::

    git.exe clone --recurse-submodules https://iffgit.fz-juelich.de/qtisas/qtisas.git
    cd qtisas
    mkdir build
    cd build
    cmake.exe .. -G "Unix Makefiles" -DCMAKE_BUILD_TYPE=Release
        -DCMAKE_MAKE_PROGRAM="C:/Qt/Tools/mingw810_32/bin/mingw32-make.exe"
        -DCMAKE_C_COMPILER="C:/Qt/Tools/mingw810_32/bin/gcc.exe"
        -DCMAKE_CXX_COMPILER="C:/Qt/Tools/mingw810_32/bin/g++.exe"
        -DHDF5_ROOT="C:/Program Files (x86)/GnuWin32"
        -DTIFF_ROOT="C:/Program Files (x86)/GnuWin32"
        -Dyaml-cpp_ROOT="C:/Program Files (x86)/GnuWin32"
        -DZLIB_ROOT="C:/Program Files (x86)/GnuWin32"
        -DCMAKE_PREFIX_PATH="C:/Qt/5.15.2/mingw81_32"
        -DPython3_ROOT_DIR="C:/Users/kk/AppData/Local/Programs/Python/Python311-32"
        -DWITH_PYTHON=ON
    cmake.exe --build . --parallel $env:NUMBER_OF_PROCESSORS

If everything is available in path, run bin/qtisas.exe.

## MacOS

Xcode command line tools is a prerequisite. Then a user might need brew or other
software packaging system. Once you have it:

    brew install cmake qt@5 hdf5 libtiff yaml-cpp
    /usr/bin/pip3 install sip pyqt5

Clone the repository:

    git clone --recurse-submodules https://iffgit.fz-juelich.de/qtisas/qtisas.git

Build the software:

    cd qtisas
    mkdir build
    cd build
    cmake .. -DCMAKE_C_COMPILER=/usr/bin/clang -DCMAKE_CXX_COMPILER=/usr/bin/clang++
        -DCMAKE_PREFIX_PATH=/opt/homebrew/opt/qt@5
        -DPython3_ROOT_DIR=/Applications/Xcode.app/Contents/Developer/Library/Frameworks/Python3.framework/Versions/Current
        -DCMAKE_BUILD_TYPE=Release -DWITH_PYTHON=ON
    cmake --build . --parallel $(sysctl -n hw.ncpu)
    open bin/qtisas.app
